pub fn create_hypervisor() -> Result<impl Hypervisor>Expand description
Creates the appropriate hypervisor for the current platform.
Errors
Returns an error if the hypervisor cannot be initialized.
pub fn create_hypervisor() -> Result<impl Hypervisor>Creates the appropriate hypervisor for the current platform.
Returns an error if the hypervisor cannot be initialized.