Hypervisor

Trait Hypervisor 

pub trait Hypervisor:
    Send
    + Sync
    + 'static {
    type Vm: VirtualMachine;

    // Required methods
    fn capabilities(&self) -> &PlatformCapabilities;
    fn create_vm(&self, config: VmConfig) -> Result<Self::Vm, HypervisorError>;
}
Main hypervisor trait for creating and managing virtual machines.

Each platform (macOS, Linux) provides its own implementation.

Required Associated Types

type Vm: VirtualMachine

The virtual machine type created by this hypervisor.

Required Methods

fn capabilities(&self) -> &PlatformCapabilities

Returns the platform capabilities.

fn create_vm(&self, config: VmConfig) -> Result<Self::Vm, HypervisorError>

Creates a new virtual machine with the given configuration.

Errors

Returns an error if the VM cannot be created.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors