BalloonStats

Struct BalloonStats 

pub struct BalloonStats {
    pub target_bytes: u64,
    pub current_bytes: u64,
    pub configured_bytes: u64,
}
Memory balloon statistics.

Fields

target_bytes: u64

Target memory size in bytes.

This is the memory size the balloon is trying to achieve.

current_bytes: u64

Current balloon size in bytes.

This is how much memory the balloon has currently claimed. actual_guest_memory = configured_memory - current_balloon_size

configured_bytes: u64

Configured VM memory size in bytes.

This is the maximum memory available to the guest when the balloon is fully deflated.

Implementations

Source

impl BalloonStats

pub const fn effective_memory(&self) -> u64

Returns the effective memory available to the guest in bytes.

This is configured_bytes - current_bytes.

pub fn target_percent(&self) -> f64

Returns the target memory as a percentage of configured memory.