VcpuSnapshot

Struct VcpuSnapshot 

pub struct VcpuSnapshot {
    pub id: u32,
    pub arch: CpuArch,
    pub x86_regs: Option<Registers>,
    pub arm64_regs: Option<Arm64Registers>,
    pub extra_state: Vec<u8>,
}
vCPU snapshot state.

Fields

id: u32

vCPU ID.

arch: CpuArch

CPU architecture.

x86_regs: Option<Registers>

x86_64 registers (if applicable).

arm64_regs: Option<Arm64Registers>

ARM64 registers (if applicable).

extra_state: Vec<u8>

Additional architecture-specific state (opaque bytes).

Implementations

Source

impl VcpuSnapshot

pub const fn new_x86(id: u32, regs: Registers) -> Self

Creates a new x86_64 vCPU snapshot.

pub const fn new_arm64(id: u32, regs: Arm64Registers) -> Self

Creates a new ARM64 vCPU snapshot.

pub fn is_placeholder(&self) -> bool

Returns true if this snapshot contains only default (zeroed) register state, i.e. it was created as a placeholder and does not represent real captured vCPU registers.