VirtioDeviceConfig

Struct VirtioDeviceConfig 

pub struct VirtioDeviceConfig {
    pub device_type: VirtioDeviceType,
    pub config: Vec<u8>,
    pub path: Option<String>,
    pub read_only: bool,
    pub tag: Option<String>,
    pub net_fd: Option<i32>,
}
VirtIO device configuration for attaching to a VM.

Fields

device_type: VirtioDeviceType

Device type.

config: Vec<u8>

Device-specific configuration.

path: Option<String>

Path to device (for block/fs devices).

read_only: bool

Whether the device is read-only.

tag: Option<String>

Tag for filesystem devices.

net_fd: Option<i32>

File descriptor for file-handle-based network attachment.

Implementations

Source

impl VirtioDeviceConfig

pub fn block(path: impl Into<String>, read_only: bool) -> Self

Creates a new block device configuration.

pub const fn network() -> Self

Creates a new network device configuration with NAT attachment.

pub const fn network_file_handle(fd: i32) -> Self

Creates a network device configuration with file-handle attachment.

The VZ framework side uses one connected datagram socket file descriptor for bidirectional frame I/O.

pub const fn console() -> Self

Creates a new console device configuration.

pub fn filesystem( path: impl Into<String>, tag: impl Into<String>, read_only: bool, ) -> Self

Creates a new filesystem device configuration.

pub const fn vsock() -> Self

Creates a new vsock device configuration.

pub const fn entropy() -> Self

Creates a new entropy device configuration.

Source

impl VirtioDeviceConfig

pub const fn balloon() -> Self

Creates a new balloon device configuration.

The balloon device allows dynamic memory management by inflating (reclaiming memory from guest) or deflating (returning memory to guest).