pub struct BalloonStats {
pub target_bytes: u64,
pub current_bytes: u64,
pub configured_bytes: u64,
}Expand description
Memory balloon statistics.
Fields
target_bytes: u64Target memory size in bytes.
This is the memory size the balloon is trying to achieve.
current_bytes: u64Current balloon size in bytes.
This is how much memory the balloon has currently claimed.
actual_guest_memory = configured_memory - current_balloon_size
configured_bytes: u64Configured VM memory size in bytes.
This is the maximum memory available to the guest when the balloon is fully deflated.
Implementations
Sourceimpl BalloonStats
impl BalloonStats
Sourcepub const fn effective_memory(&self) -> u64
pub const fn effective_memory(&self) -> u64
Returns the effective memory available to the guest in bytes.
This is configured_bytes - current_bytes.
Sourcepub fn target_percent(&self) -> f64
pub fn target_percent(&self) -> f64
Returns the target memory as a percentage of configured memory.